@@ -27,6 +27,7 @@ class ChatGPT:
         auth_type: str = None,
         proxy: str = None,
         verbose: bool = False,
+        window_size: tuple = (800, 600),
     ) -> None:
         '''
         Initialize the ChatGPT class\n
@@ -50,6 +51,7 @@ class ChatGPT:
         self.__email = email
         self.__password = password
         self.__auth_type = auth_type
+        self.__window_size = window_size
         if self.__auth_type not in [None, 'google', 'windowslive']:
             raise ValueError('Invalid authentication type')
         self.__session_token = session_token
@@ -102,7 +104,7 @@ class ChatGPT:
 
         # Start the browser
         options = uc.ChromeOptions()
-        options.add_argument('--window-size=800,600')
+        options.add_argument('--window-size=%s,%s' % self.__window_size)
         if self.__proxy:
             options.add_argument(f'--proxy-server={self.__proxy}')
         try:
@@ -384,14 +386,14 @@ class ChatGPT:
 
         # Wait for the response to be ready
         self.__verbose_print('[send_msg] Waiting for completion')
-        WebDriverWait(self.driver, 90).until_not(
+        WebDriverWait(self.driver, 600).until_not(
             EC.presence_of_element_located((By.CLASS_NAME, 'result-streaming'))
         )
 
         # Get the response element
         self.__verbose_print('[send_msg] Finding response element')
         response = self.driver.find_elements(
-            By.XPATH, "//div[starts-with(@class, 'request-:')]"
+            By.XPATH, "//div[starts-with(@class, 'markdown prose break-words')]"
         )[-1]
 
         # Check if the response is an error
